/*
	IBAN Checker - Checks format and checksum of IBAN numbers
	Copyright © 2009-2010 Harry Whitfield

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
	MA	02110-1301	USA

	IBAN Checker - version 1.2
	6 March, 2010
	Copyright 2009-2010 Harry Whitfield
	mailto:g6auc@arrl.net

	The ibanData table (below) is derived from data in the IBAN REGISTRY.
	See below for Legal Notices concerning the IBAN REGISTRY.
*/

/*
Registration Authority for ISO 13616

The Society for Worldwide Interbank Financial Telecommunication SCRL, SWIFT, has
been designated by the ISO Technical Management Board to act as the Registration
Authority for ISO 13616.

IBAN REGISTRY

The registry provides detailed information about all ISO 13616-compliant
national IBAN formats.
Release 17 – January 2010

January 2010 20100102_IBAN_Registry 1

Legal Notices

Copyright

Copyright © and database producer's rights owned by S.W.I.F.T. SCRL ("SWIFT"),
avenue Adèle 1, B-1310 La Hulpe, Belgium, 2008. All rights reserved.

This Registry is public, and may be copied or otherwise distributed provided it
is not used as a source of profit. Any such copy or reproduction will include
the following: acknowledgement of the source, reference and date of publication,
and all notices set out on this page.

Disclaimer

This publication is supplied for information purposes only, and shall not be
binding nor shall it be construed as constituting any obligation,
representation, or warranty on the part of SWIFT. The information in this
publication is the latest available at the date of its production, and may
change from time to time.

Translations

SWIFT official documentation is published in English only. Even where SWIFT has
exceptionally permitted the translation of the documentation, only the English
version is valid.

Trademarks and Patents

SWIFT, S.W.I.F.T., the SWIFT logos, Sibos, SWIFTNet, SWIFTAlliance,
SWIFTStandards, SWIFTReady, and Accord are trademarks of S.W.I.F.T. SCRL. Other
SWIFT-derived service and product names, such as but not limited to
SWIFTSolutions and SWIFTSupport, are tradenames of S.W.I.F.T. SCRL. SWIFT is the
trading name of S.W.I.F.T. SCRL. All other product or company names that may be
mentioned in this publication are tradenames, trademarks, or registered
trademarks of their respective owners. Patent pending: SWIFTNet.
Produced in January 2008
*/

var ibanData = [["AL", "Albania",				 28, /AL\d{10}[A-Za-z0-9]{16}/],
				["AD", "Andorra",				 24, /AD\d{10}[A-Za-z0-9]{12}/],
				["AT", "Austria",		  		 20, /AT\d{18}/],
				["BE", "Belgium",		  		 16, /BE\d{14}/],
				["BA", "Bosnia and Herzegovina", 20, /BA\d{18}/],
				["BG", "Bulgaria",				 22, /BG\d{2}[A-Z]{4}\d{6}[A-Za-z0-9]{8}/],
				["HR", "Croatia",		  		 21, /HR\d{19}/],
				["CY", "Cyprus",				 28, /CY\d{10}[A-Za-z0-9]{16}/],
				["CZ", "Czech Republic",  		 24, /CZ\d{22}/],
				["DK", "Denmark",		  		 18, /DK\d{16}/],
				["FO", "Denmark",		  		 18, /FO\d{16}/],
				["GL", "Denmark",		  		 18, /GL\d{16}/],
				["EE", "Estonia",				 20, /EE\d{18}/],
				["FI", "Finland",				 18, /FI\d{16}/],
				["FR", "France",				 27, /FR\d{12}[A-Za-z0-9]{11}\d{2}/],
				["PF", "French Polynesia",			  27, /PF\d{12}[A-Za-z0-9]{11}\d{2}/],
				["TF", "French Southern Territories", 27, /TF\d{12}[A-Za-z0-9]{11}\d{2}/],
				["YT", "Mayotte",				 	  27, /YT\d{12}[A-Za-z0-9]{11}\d{2}/],
				["NC", "New Caledonia",				  27, /NC\d{12}[A-Za-z0-9]{11}\d{2}/],
				["PM", "Saint Pierre et Miquelon",	  27, /PM\d{12}[A-Za-z0-9]{11}\d{2}/],
				["WF", "Wallis and Futuna Islands",	  27, /WF\d{12}[A-Za-z0-9]{11}\d{2}/],
				["DE", "Germany",				 22, /DE\d{20}/],
				["GI", "Gibraltar",				 23, /GI\d{2}[A-Z]{4}[A-Za-z0-9]{15}/],
				["GR", "Greece",				 27, /GR\d{9}[A-Za-z0-9]{16}/],
				["HU", "Hungary",				 28, /HU\d{26}/],
				["IS", "Iceland",		  		 26, /IS\d{24}/],
				["IE", "Ireland",		  		 22, /IE\d{2}[A-Z]{4}\d{14}/],
				["IL", "Israel",				 23, /IL\d{21}/],
				["IT", "Italy",					 27, /IT\d{2}[A-Z]\d{10}[A-Za-z0-9]{12}/],
				["LV", "Latvia",				 21, /LV\d{2}[A-Z]{4}[A-Za-z0-9]{13}/],
				["LB", "Lebanon",				 28, /LB\d{6}[A-Za-z0-9]{20}/],
				["LI", "Liechtenstein",	  		 21, /LI\d{7}[A-Za-z0-9]{12}/],
				["LT", "Lithuania",				 20, /LT\d{18}/],
				["LU", "Luxembourg",	  		 20, /LU\d{5}[A-Za-z0-9]{13}/],
				["MK", "Macedonia",		  		 19, /MK\d{5}[A-Za-z0-9]{10}\d{2}/],
				["MT", "Malta",					 31, /MT\d{2}[A-Z]{4}\d{5}[A-Za-z0-9]{18}/],
				["MU", "Mauritius",		  		 30, /MU\d{2}[A-Z]{4}\d{19}[A-Z]{3}/],
				["MC", "Monaco",		  		 27, /MC\d{12}[A-Za-z0-9]{11}\d{2}/],
				["ME", "Montenegro",			 22, /ME\d{20}/],
				["NL", "Netherlands",			 18, /NL\d{2}[A-Z]{4}\d{10}/],
				["NO", "Norway",		  		 15, /NO\d{13}/],
				["PL", "Poland",				 28, /PL\d{26}/],
				["PT", "Portugal",		  		 25, /PT\d{23}/],
				["RO", "Romania",				 24, /RO\d{2}[A-Z]{4}[A-Za-z0-9]{16}/],
				["SM", "San Marino",			 27, /SM\d{2}[A-Z]\d{10}[A-Za-z0-9]{12}/],
				["SA", "Saudi Arabia",			 24, /SA\d{4}[A-Za-z0-9]{18}/],
				["RS", "Serbia",		  		 22, /RS\d{20}/],
				["SK", "Slovak Republic", 		 24, /SK\d{22}/],
				["SI", "Slovenia",				 19, /SI\d{17}/],
				["ES", "Spain",			  		 24, /ES\d{22}/],
				["SE", "Sweden",		  		 24, /SE\d{22}/],
				["CH", "Switzerland",	  		 21, /CH\d{7}[A-Za-z0-9]{12}/],
				["TN", "Tunisia",		  		 24, /TN\d{22}/],
				["TR", "Turkey",				 26, /TR\d{7}[A-Za-z0-9]{17}/],
				["GB", "United Kingdom",  		 22, /GB\d{2}[A-Z]{4}\d{14}/]];
				