/*
	IBAN Checker - Checks format and checksum of IBAN numbers
	Copyright © 2009-2010 Harry Whitfield

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
	MA	02110-1301	USA

	IBAN Checker - version 1.2
	6 March, 2010
	Copyright 2009-2010 Harry Whitfield
	mailto:g6auc@arrl.net
*/

/*global checkIban, eprint, main_window, mod97_10, displayLicense */

/*members altKey, appendChild, bgColor, bgOpacity, checked, color, 
    colorize, contextMenuItems, data, editable, enabled, event, font, 
    hAlign, hOffset, height, keyString, length, lines, onDragDrop, 
    onDragEnter, onDragExit, onGainFocus, onKeyPress, onLoseFocus, 
    onMouseDown, onMouseDrag, onMouseEnter, onMouseExit, onMouseUp, 
    onSelect, opacity, open, push, rejectKeyPress, replace, scrollbar, 
    setStyle, size, src, style, substring, title, tooltip, vOffset, value, 
    width, widthPref, x
*/

var menuItem;
var contextMenuItems = null;

var normalButtons = null, activeButtons = null, focusButtons = null,
	setUp = null, command = null, report = null, dragbox = null;

function newImage(parent, src, hOffset, vOffset, width, height, hAlign, opacity, colorize) {
	var o = new Image();
	o.src      = src;
	o.hOffset  = hOffset;
	o.vOffset  = vOffset;
	o.width    = width;
	o.height   = height;
	o.hAlign   = hAlign;
	o.opacity  = opacity;
	o.colorize = colorize;
	parent.appendChild(o);
	return o;
}

function newText(parent, hOffset, vOffset, width, height, hAlign, font, style, size, color, opacity, bgColor, bgOpacity) {
	var o = new Text();
	o.hOffset   = hOffset;
	o.vOffset   = vOffset;
	o.width     = width;
	o.height    = height;
	o.hAlign    = hAlign;
	o.font      = font;
	o.style     = style;
	o.size      = size;
	o.color     = color;
	o.opacity   = opacity;
	o.bgColor   = bgColor;
	o.bgOpacity = bgOpacity;
	parent.appendChild(o);
	return o;
}

function newTextArea(parent, hOffset, vOffset, width, height, hAlign, font, style, size, color, opacity, bgColor, bgOpacity, scrollbar, editable) {
	var o = new TextArea();
	o.hOffset   = hOffset;
	o.vOffset   = vOffset;
	o.width     = width;
	o.height    = height;
	o.hAlign    = hAlign;
	o.font      = font;
	o.style     = style;
	o.size      = size;
	o.color     = color;
	o.opacity   = opacity;
	o.bgColor   = bgColor;
	o.bgOpacity = bgOpacity;
	o.scrollbar = scrollbar;
	o.editable  = editable;
	parent.appendChild(o);
	return o;
}

function newContextMenuItem(title, onSelect, enabled, checked) {
	var o = new MenuItem();
	o.title    = title;
	o.onSelect = onSelect;
	o.enabled  = enabled;
	o.checked  = checked;
	return o;
}

/*
function newButton(parent, src, srcDown, hOffset, vOffset, width, height, hAlign, opacity, colorize, clickAction) {
	var o = newImage(parent, src, hOffset, vOffset, width, height, hAlign, opacity, colorize);
	o.srcUp  = src;
	o.srcDown  = srcDown;
	o.within = false;
	o.onMouseUp = function () {
		if (this.within) {
			this.src = src;
			clickAction();
		}
	};
	o.onMouseDown = function () { 
		this.within = true;
		this.src = srcDown;
	};
	o.onMouseEnter = function () { 
		this.within = true;
		this.src = srcDown;
	};
	o.onMouseExit = function () { 
		this.within = false;
		this.src = src;
	};
	return o;
}

function addDropHandlers(button, dropAction) {
	button.onDragDrop = function () {
		button.src = button.srcUp;
		button.colorize = null;
		dropAction();
	};
	button.onDragEnter = function () {
		button.src = button.srcDown;
		button.colorize = "#00FF00";
	};
	button.onDragExit = function () {
		button.src = button.srcUp;
		button.colorize = null;
	};
}
*/

var minWidth = 236; 
var maxWidth = 320;
var hasFocus = false;
var gWidth   = preferences.widthPref.value;

var leftbg 		= newImage(main_window, "Resources/Images/leftbg.png", 0, 0, 30, 79, "left", 255, null);
var midbg 		= newImage(main_window, "Resources/Images/midbg.png", 30, 0, 558, 79, "left", 255, null);
var rightbg 	= newImage(main_window, "Resources/Images/rightbg.png", 587, 0, 30, 79, "left", 255, null);

var redButtonWithin = false; 
var redButton 	= newImage(main_window, "Resources/Images/red.png", 8, 5, 14, 14, "left", 255, null);
redButton.tooltip = "Close the widget.";
redButton.onMouseUp = function () {
	if (redButtonWithin) {
		normalButtons();
		closeWidget();
	}
};
redButton.onMouseDown = function () {
	redButtonWithin = true;
	activeButtons();
};
redButton.onMouseEnter = function () {
	redButtonWithin = true;
	activeButtons();
};
redButton.onMouseExit = function () {
	redButtonWithin = false;
	focusButtons();
};

//code to clear the data fields
var clearData = function () {
	command.data = "";
	report.data = "";
	command.tooltip = "Enter an IBAN number, then press the return (or enter) key.";
};

var amberButtonWithin = false; 
var amberButton	= newImage(main_window, "Resources/Images/amber.png", 29, 5, 14, 14, "left", 255, null);
amberButton.tooltip = "Clear the data field.";
amberButton.onMouseUp = function () { 
	if (amberButtonWithin) {
		normalButtons();
		clearData();
	}
};
amberButton.onMouseDown = function () { 
	amberButtonWithin = true;
	activeButtons();
};
amberButton.onMouseEnter = function () { 
	amberButtonWithin = true;
	activeButtons();
};
amberButton.onMouseExit = function () { 
	amberButtonWithin = false;
	focusButtons();
};

var toggleSize = function () {
	if (main_window.width == gWidth) {
		setUp(maxWidth);
	} else {
		setUp(gWidth);
	}
};

var greenButtonWithin = false; 
var greenButton	= newImage(main_window, "Resources/Images/green.png", 50, 5, 14, 14, "left", 255, null);
greenButton.tooltip = "";

greenButton.onMouseUp = function () {
	if (greenButtonWithin) {
		normalButtons();
		toggleSize();
	}
};
greenButton.onMouseDown = function () {
	greenButtonWithin = true;
	activeButtons();
};
greenButton.onMouseEnter = function () {
	greenButtonWithin = true;
	activeButtons();
};
greenButton.onMouseExit = function () {
	greenButtonWithin = false;
	focusButtons();
};

normalButtons = function () {
	redButton.src   = "Resources/Images/red.png";
	amberButton.src = "Resources/Images/amber.png";
	greenButton.src = "Resources/Images/green.png";
};

activeButtons = function () {
	redButton.src   = "Resources/Images/redCross.png";
	amberButton.src = "Resources/Images/amberMinus.png";
	greenButton.src = "Resources/Images/greenPlus.png";
};

focusButtons = function () {
	if (hasFocus) {
		redButton.src   = "Resources/Images/red.png";
		amberButton.src = "Resources/Images/amber.png";
		greenButton.src = "Resources/Images/green.png";
	} else {
		redButton.src   = "Resources/Images/grey.png";
		amberButton.src = "Resources/Images/grey.png";
		greenButton.src = "Resources/Images/grey.png";
	}
};

var cmdHOff = 10;

var comBgSelLeft   = newImage(main_window, "Resources/Images/comBgSelLeft.png",  cmdHOff -   3, 31,  23, 28, "left", 0, null);
var comBgSelMiddle = newImage(main_window, "Resources/Images/comBgSelMidd.png",  cmdHOff +  20, 31, 100, 28, "left", 0, null);
var comBgSelRight  = newImage(main_window, "Resources/Images/comBgSelRight.png", cmdHOff + 120, 31,  23, 28, "left", 0, null);

var comBgLeft   = newImage(main_window, "Resources/Images/comBgLeft.png",  cmdHOff,       34,  20, 22, "left", 255, null);
var comBgMiddle = newImage(main_window, "Resources/Images/comBgMidd.png",  cmdHOff +  20, 34, 100, 22, "left", 255, null);
var comBgRight  = newImage(main_window, "Resources/Images/comBgRight.png", cmdHOff + 120, 34,  20, 22, "left", 255, null);

//code to call the checkIban function
var process = function () {
	var data = command.data;
	eprint("---- ---- ---- ---- ---- ---- ---- ---- ----");
	eprint("IBAN " + data);
	data = data.replace(/ /g, "");
	var cc = data.substring(0, 2);	
	var kk = data.substring(2, 4);
	var rs = checkIban(data, system.event.altKey);
	var cs = rs[0], tooltip = rs[1];
	command.tooltip = tooltip;
	eprint(tooltip);
	if (cs == 1) {
		report.color = "#000000";
		report.data = "Valid Format and Checksum";
	} else {
		cs = -cs;
		if ((cs < 100) && (kk == "00") && system.event.altKey) {
			cs = mod97_10(String(98 - cs));
			if (cs.length == 1) {
				cs = "0" + cs;
			}
			report.color = "#0000FF";
			report.data  = "Calculated Check Digits: " + cs;
			tooltip  = "Replacing " + cc + "00 by " + cc + cs;
			tooltip += " will produce a number that passes the checksum test.";
			tooltip += "\nHowever, that does NOT mean that the resulting number is a valid IBAN.";
			command.tooltip = tooltip;
			eprint("Calculated Check Digits: " + cs);
		} else {
			report.color = "#FF0000";
			report.data = "Invalid Format or Checksum";
		}
	}
};

command		= newTextArea(main_window, cmdHOff + 10, 37, 120, 17, "left", "Arial, Courier New", "font-weight: normal;", 14, "#000000", 255, "#FFFFFF", 255, false, true);
command.lines = 1;
command.tooltip	 = "Enter an IBAN number, then press the RETURN (or ENTER) key."; 
command.onGainFocus = function () {
	comBgSelLeft.opacity = comBgSelMiddle.opacity = comBgSelRight.opacity = 255;
	comBgLeft.opacity    = comBgMiddle.opacity    = comBgRight.opacity    = 0;
};
command.onLoseFocus = function () {
	comBgLeft.opacity    = comBgMiddle.opacity    = comBgRight.opacity    = 255;
	comBgSelLeft.opacity = comBgSelMiddle.opacity = comBgSelRight.opacity = 0;
};
command.onKeyPress = function () {
	if ((system.event.keyString == "Return") || (system.event.keyString == "Enter")) {
		command.rejectKeyPress();
		process();
	} else {
		report.data = "";
		command.tooltip = "Enter an IBAN number, then press the return (or enter) key."; 
	}
};
command.onDragDrop = function () {
	if (system.event.data[0] == 'string') {
		command.data = system.event.data[1];
	}
	command.bgColor = "#FFFFFF";
	report.data = "";
	command.tooltip = "Enter an IBAN number, then press the return (or enter) key."; 
};
command.onDragEnter = function () {
	command.bgColor = "#00FF00";
};
command.onDragExit = function () {
	command.bgColor = "#FFFFFF";
};

var mainTitle = newText(main_window, 184, 14, 100, 18, "center", "Lucida Grande", "bold", 12, "#000000", 255, "#FFFFFF", 0);
mainTitle.data = "IBAN Checker";
mainTitle.style.setStyle("font-family: 'Lucida Grande','Lucida Sans Unicode'; text-align: center");

report = newText(main_window, 128, 72, 256, 16, "center", "Arial", "bold", 12, "#000000", 255, "#FFFFFF", 0);
report.data = "";
report.style.setStyle("font-family: 'Arial','Courier New'; text-align: center");

setUp = function (width) {
	if (width < minWidth) {
		width = minWidth;
	}
	if (width > maxWidth) {
		width = maxWidth;
	}

	main_window.width = width;
	midbg.width       = width - 60;
	rightbg.hOffset   = width - 30;
	
	comBgRight.hOffset = width - 30;
	comBgMiddle.width  = width - 50;
	
	comBgSelRight.hOffset = width - 30;
	comBgSelMiddle.width  = width - 50;

	command.width  = width - 40;
	report.hOffset = width / 2;
	
	mainTitle.hOffset = width / 2;
	dragbox.hOffset   = width - 20;

	updateNow();
	return width;
};

dragbox 	= newImage(main_window, "Resources/Images/dragbox.png", 478, 59, 15, 15, "left", 255, null);
dragbox.onMouseDrag = function () {
	gWidth = setUp(dragbox.hOffset + system.event.x + 8);
};

contextMenuItems = [];	
menuItem = newContextMenuItem("Display Help File...", function () {
	filesystem.open('Resources/Help.pdf');
}, true, false);
contextMenuItems.push(menuItem);
menuItem = newContextMenuItem("Display License Agreement...", function () {
	displayLicense();
}, true, false);
contextMenuItems.push(menuItem);
main_window.contextMenuItems = contextMenuItems;

// set up various handlers
main_window.onGainFocus = function () {
	hasFocus = true;
	focusButtons();
};
main_window.onLoseFocus = function () {
	hasFocus = false;
	focusButtons();
};

gWidth = setUp(gWidth); 
